@@ -884,6 +884,11 @@ attribute(void *ctx, const xmlChar *fullname, const xmlChar *value)
 	    ctxt->valid &= xmlValidateOneAttribute(&ctxt->vctxt, ctxt->myDoc,
 					       ctxt->node, ret, value);
 	 */
+	if (value[0] == 0) {
+	    if ((ctxt->sax != NULL) && (ctxt->sax->error != NULL))
+		ctxt->sax->error(ctxt->userData, 
+		     "Empty namespace name for prefix %s\n", name);
+	}
 	/* a standard namespace definition */
 	xmlNewNs(ctxt->node, value, name);
 	xmlFree(ns);
@@ -1277,7 +1282,8 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
      * set the namespace node, making sure that if the default namspace
      * is unbound on a parent we simply kee it NULL
      */
-    if ((ns != NULL) && (ns->href != NULL) && (ns->href[0] != 0))
+    if ((ns != NULL) && (ns->href != NULL) &&
+	((ns->href[0] != 0) || (ns->prefix != NULL)))
 	xmlSetNs(ret, ns);
 
     /*
