@@ -26,21 +26,21 @@ extern void xmlCheckVersion(int version);
  *
  * the version string like "1.2.3"
  */
-#define LIBXML_DOTTED_VERSION "2.4.16"
+#define LIBXML_DOTTED_VERSION "2.4.17"
 
 /**
  * LIBXML_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXML_VERSION 20416
+#define LIBXML_VERSION 20417
 
 /**
  * LIBXML_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXML_VERSION_STRING "20416"
+#define LIBXML_VERSION_STRING "20417"
 
 /**
  * LIBXML_TEST_VERSION:
@@ -48,7 +48,7 @@ extern void xmlCheckVersion(int version);
  * Macro to check that the libxml version in use is compatible with
  * the version the software has been compiled against
  */
-#define LIBXML_TEST_VERSION xmlCheckVersion(20416);
+#define LIBXML_TEST_VERSION xmlCheckVersion(20417);
 
 #ifndef VMS
 #if 0
@@ -108,6 +108,15 @@ extern void xmlCheckVersion(int version);
 #define LIBXML_HTML_ENABLED
 #endif
 
+/**
+ * LIBXML_C14N_ENABLED:
+ *
+ * Whether the Canonicalization support is configured in
+ */
+#if 1
+#define LIBXML_C14N_ENABLED
+#endif
+
 /**
  * LIBXML_CATALOG_ENABLED:
  *
